<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.vlogiclabs.com
 * @since      1.0.0
 *
 * @package    Instant_Funnel_Machine
 * @subpackage Instant_Funnel_Machine/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Instant_Funnel_Machine
 * @subpackage Instant_Funnel_Machine/admin
 * @author     Rinkesh <khanalmaya6@gmail.com>
 */
class Instant_Funnel_Machine_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        $this->load_dependencies();
        
        
	}
	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * @since    1.0.0
	 * @access   private
	 */

        public function load_dependencies() {
        
         /**
	 * The class responsible for updating funnel users details in wp_usermeta table
	 * 
	 */
	 /* class-curl used to accept data and url & execute the curl**/
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-curl.php';
        
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-funnel-user.php';
        
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-xml-read.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-create-page.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-load-funnel.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-funnel-subscriber.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-delete-funnel.php';
        //require_once plugin_dir_path(dirname(__FILE__)) . 'includes/wp_autoupdate.php';
        //require_once plugin_dir_path(dirname(__FILE__)) . 'update.php';
		
        } 
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Instant_Funnel_Machine_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Instant_Funnel_Machine_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/instant-funnel-machine-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'bootstrap.min', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		
		// load jquery validation plugin css 
        
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Instant_Funnel_Machine_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Instant_Funnel_Machine_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		//wp_enqueue_script( 'jquery.min', plugin_dir_url( __FILE__ ) . 'js/jquery.min.js', array(), $this->version, false );
		
       wp_enqueue_script( 'jquery.validate.min', plugin_dir_url( __FILE__ ) . 'js/jquery.validate.min.js', array('jquery'), $this->version, false ); 
        
        //wp_enqueue_script( 'jquery.validate', plugin_dir_url( __FILE__ ) . 'js/jquery.validate.js', array(), $this->version, false );
        
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/instant-funnel-machine-admin.js', array('jquery' ), $this->version, false );
		wp_enqueue_script( 'bootstrap.min', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array('jquery' ), $this->version, false );
		
		wp_localize_script( 'ajax-script', 'ajax_object',array( 'ajax_url' => admin_url( 'admin-ajax.php' ), 'data' => '' ) );
		
		
	}
	
	
	 /*
     * Adds the plugin menu item to dashboard
     * @since    1.0.0
     */
	public function funnel_menu(){
		add_menu_page('Instant Funnel Machine', 'Instant Funnel Machine', 'administrator', 'instant-funnel-machine',array(&$this, 'funnel_settings'));
		 add_submenu_page( 'instant-funnel-machine', 'Install Funnel Tab', 'Install Funnel Tab', 'administrator', 'install-funnel-tab', array(&$this, 'install_funnel_tab') );
		 add_submenu_page( 'instant-funnel-machine', 'My Funnels Tab', 'My Funnels Tab', 'administrator', 'my-funnels-tab', array(&$this, 'my_funnels_tab') );
		// add_submenu_page( 'instant-funnel-machine', 'Check Updates', 'Check Updates', 'administrator', 'check-updates-tab', array(&$this, 'updates') );
	}
	 // Check user is already registered to the software and throws error if user is removed or disabled from Software.
	public function user_authentication()
	{
		 $key = "funnel_user";
         $id = get_current_user_id();
        $user_info = get_user_meta($id, $key, TRUE);
		if(isset($user_info) && !empty($user_info)){
			$user_data = array(
			  "email"       => $user_info['email'],
             "password"    => $user_info['password'],
             "license_key" => $user_info['license'],
			);
			 $url = "http://dev.instantfunnelmachine.com/index.php/Api/authenticate/";
             $ex_curl = new Curl();
             $apiResponse =  $ex_curl->call_curl($user_data,$url);
			// print_r($apiResponse);	
			 if($apiResponse['error']==1)
			 {
				  $data = array(
				   "email"    =>  $apiResponse['email'],
				   "password" =>  $apiResponse['password'],
				   "license"  =>  $apiResponse['license_key'],
				   );
				// die($apiResponse['message']);
				delete_user_meta($id, $key, $data);
			 }
		}
	    
	}
	
	
	public function funnel_settings()
	{
	   $key = "funnel_user";
       $id = get_current_user_id();
       $user_info = get_user_meta($id, $key, TRUE);
	//print_r($user_info);	
	    if(($_POST['funnelsubmitted'])) {	
 
           $email    =  $_POST['email'];
           $password = $_POST['password'];
           $license  = $_POST['license'];
           
            $funnelSettings = array(
             "email"       => $email,
             "password"    => $password,
             "license_key" => $license,
          
            );
     $url = "http://dev.instantfunnelmachine.com/index.php/Api/authenticate/";
     $ex_curl = new Curl();
    $apiResponse =  $ex_curl->call_curl($funnelSettings,$url);
	     
	          if(!$apiResponse['error'])  { 
	          $data = array(
		   "email"    =>  $apiResponse['email'],
		   "password" =>  $apiResponse['password'],
		   "license"  =>  $apiResponse['license_key'],
		   );
		   //print_r($data);
		    $funnel_user = new Funnel_User();
		    $response =  $funnel_user->add_user($data);

	     }
			
	}
	
	include_once 'partials/registration-tab-display.php';	
}

// Start second Tab function
   function install_funnel_tab()
   {
       $key = "funnel_user";
       $id = get_current_user_id();
       $user = get_user_meta($id, $key, TRUE);
       //print_r($user);
       if(isset($user["email"])){
       $data = array(
       "emailid" => $user["email"],
       );
	    }
      $url = "http://dev.instantfunnelmachine.com/index.php/Api/get_funnels/";
     $ex_curl = new Curl();
    $apiResponse =  $ex_curl->call_curl($data,$url);
  
   
     if(isset($_POST['funnel_id']))
     {
	    $funnel_id = $_POST['funnel_id'];
	 	
	 	//print_r($funnel);
	   $load = new Load_Funnel();
	   $get = $load->load_funnel_by_id($funnel_id);
	   
	 }
	 // change the page title
	 if(($_POST['postidsubmit'])) 
	 {	
	  $post_id    = $_POST['postid'];
	   $page_title = $_POST['page_title'];
	   $page_obj = new Create_Pages();
       $return_data = $page_obj->change_page_title($post_id,$page_title);
	 } 
	 // change the page Slug
	 if(($_POST['postidsubmit2'])) 
	 {	
	  $post_id    = $_POST['post_id'];
	   $page_slug = $_POST['page_slug'];
	   $page_obj = new Create_Pages();
       $return_data = $page_obj->change_page_slug($post_id,$page_slug);
	 }
	 
     
     include_once 'partials/install-funnel-tab-display.php';	
   }
   
   // Third Tab display
   function my_funnels_tab()
   {
	   $key = "funnel_user";
       $id = get_current_user_id();
       $user = get_user_meta($id, $key, TRUE);
	   
	   
	   include_once 'partials/my-funnels-tab-display.php';
   }
   
   // ajax request
   function delete_funnel_action()
   {
	    $funnelid = $_POST['data'];
	   $delete  = new Funnel_Delete();
	   $results = $delete->delete_funnel_by_id($funnelid);
   }
   
    function updates()
	{
	    $current_version = '1.1';
	    $plugin_remote_path = 'http://dev.instantfunnelmachine.com/plugin/update.php';
	   $plugin_slug = 'instant-funnel-machine/instant-funnel-machine.php';
		$obj = new wp_auto_update( $current_version, $plugin_remote_path, $plugin_slug);	
	   if($obj){
		    $a= $obj->getRemote_version();
		    $remote_version =  $a->new_version;
			//print_r($a); 
			if(version_compare( $current_version, $remote_version, '<' )){
				echo "<div class='wrap'><div class='update-nag notice'>A Newer version plugin is available.Update with new version is: ".$remote_version." <a href='javascript:;' class='button-primary btn_update'>Click here to Update</a></div></div>";
				
			}else{
				echo "<div class='wrap'><div class='updated notice'>Plugin is installed updated version. Your current version is: ".$current_version."</div></div>";
			}
		 
	  }
	  else
	  {
		  echo "Failed";
	  }
	  
	   
	}
	
	
}