<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://www.vlogiclabs.com
 * @since             1.0.0
 * @package           Instant_Funnel_Machine
 *
 * @wordpress-plugin
 * Plugin Name:       Instant Funnel Machine
 * Plugin URI:        http://instantfunnelmachine.com/
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.0.10
 * Author:            Trevor McHaffie, BAE Enterprises
 * Author URI:        http://instantfunnelmachine.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       instant-funnel-machine
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-instant-funnel-machine-activator.php
 */
function activate_instant_funnel_machine() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-instant-funnel-machine-activator.php';
    Instant_Funnel_Machine_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-instant-funnel-machine-deactivator.php
 */
function deactivate_instant_funnel_machine() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-instant-funnel-machine-deactivator.php';
    Instant_Funnel_Machine_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_instant_funnel_machine');
register_deactivation_hook(__FILE__, 'deactivate_instant_funnel_machine');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-instant-funnel-machine.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_instant_funnel_machine() {

    $plugin = new Instant_Funnel_Machine();
    $plugin->run();
}

run_instant_funnel_machine();

require_once plugin_dir_path(__FILE__) . 'includes/class-page-template.php';
add_action('plugins_loaded', array('IfmPageTemplater', 'get_instance'));

add_action('template_redirect', 'intercept_template', 1);

function intercept_template() {
    if (is_page()) {
        global $post;

        //remove_filter( 'template_include');
        if (has_filter('template_include', 'op_template_include') && get_post_meta($post->ID, '_wp_page_template', true) != '') {

            remove_filter('template_include', 'op_template_include');
        }
    }
}
// This option for optimize press to enable the externam plugin comptability 
update_option('optimizepress_op_other_plugins','on');

require_once plugin_dir_path(__FILE__) . 'includes/wp_autoupdate.php';
add_action('init', 'actiavte');

function actiavte() {
    $current_version = '1.0.10';
    $plugin_remote_path = 'http://dev.instantfunnelmachine.com/plugin/update.php';
    $plugin_slug = plugin_basename(__FILE__);
    $obj = new wp_auto_update($current_version, $plugin_remote_path, $plugin_slug);
}

# Backup the templates folder in plugin before updating the plugin.

function hpt_copyr($source, $dest)
{
    // Check for symlinks
    if (is_link($source)) {
        return symlink(readlink($source), $dest);
    }

    // Simple copy for a file
    if (is_file($source)) {
        return copy($source, $dest);
    }

    // Make destination directory
    if (!is_dir($dest)) {
        mkdir($dest);
    }

    // Loop through the folder
    $dir = dir($source);
    while (false !== $entry = $dir->read()) {
        // Skip pointers
        if ($entry == '.' || $entry == '..') {
            continue;
        }

        // Deep copy directories
        hpt_copyr("$source/$entry", "$dest/$entry");
    }

    // Clean up
    $dir->close();
    return true;
}
function hpt_remove($dir) { 
   if (is_dir($dir)) { 
     $objects = scandir($dir); 
     foreach ($objects as $object) { 
       if ($object != "." && $object != "..") { 
         if (is_dir($dir."/".$object))
           rrmdir($dir."/".$object);
         else
           unlink($dir."/".$object); 
       } 
     }
     rmdir($dir); 
   } 
 }
function hpt_backup()
{
	$to = dirname(__FILE__)."/../ifm_templates/";
	$from = dirname(__FILE__)."/templates/";
	hpt_copyr($from, $to);
}
function hpt_recover()
{
	$from = dirname(__FILE__)."/../ifm_templates/";
	$to = dirname(__FILE__)."/templates/";
	hpt_copyr($from, $to);
	if (is_dir($from)) {
		hpt_remove($from);
	}
}
add_filter('upgrader_pre_install', 'hpt_backup', 10, 2);
add_filter('upgrader_post_install', 'hpt_recover', 10, 2);